@@ -16,7 +16,11 @@
 set -e
 
 PROGNAME="${0##*/}"
-CACHEDIR=~/.devscripts_cache
+# TODO: Remove use of OLDCACHEDDIR post-Stretch
+OLDCACHEDIR=~/.devscripts_cache
+OLDCACHEDDIFF="${OLDCACHEDIR}/wnpp-diff"
+CACHEDIR=${XDG_CACHE_HOME:-$HOME/.cache}
+CACHEDIR=${CACHEDIR%/}/devscripts
 CACHEDDIFF="${CACHEDIR}/wnpp-diff"
 CURLORWGET=""
 GETCOMMAND=""
@@ -37,6 +41,9 @@ Modifications: Julian Gilbey <jdg@debian.org>"
 }
 
 wnppdiff () {
+    if [ -f "$OLDCACHEDDIFF" ]; then
+        mv "$OLDCACHEDDIFF" "$CACHEDDIFF"
+    fi
     if [ ! -f "$CACHEDDIFF" ]; then
         # First use
         comm -12 $WNPP_PACKAGES $INSTALLED | sed -e 's/+/\\+/g' | \
@@ -94,16 +101,16 @@ fi
 # matching lines and then processing them, this attempts to sed
 # every line; those which succeed execute the 'p' command, those
 # which don't skip over it to the label 'd'
-$GETCOMMAND $WNPPTMP http://www.debian.org/devel/wnpp/orphaned || \
-    { echo "$PROGNAME: $CURLORWGET http://www.debian.org/devel/wnpp/orphaned failed" >&2; exit 1; }
+$GETCOMMAND $WNPPTMP https://www.debian.org/devel/wnpp/orphaned || \
+    { echo "$PROGNAME: $CURLORWGET https://www.debian.org/devel/wnpp/orphaned failed" >&2; exit 1; }
 sed -ne 's/.*<li><a href="https\?:\/\/bugs.debian.org\/\([0-9]*\)">\([^:<]*\)[: ]*\([^<]*\)<\/a>.*/O \1 \2 -- \3/; T d; p; : d' $WNPPTMP > $WNPP
 
-$GETCOMMAND $WNPPTMP http://www.debian.org/devel/wnpp/rfa_bypackage || \
-    { echo "$PROGNAME: $CURLORWGET http://www.debian.org/devel/wnpp/rfa_bypackage" >&2; exit 1; }
+$GETCOMMAND $WNPPTMP https://www.debian.org/devel/wnpp/rfa_bypackage || \
+    { echo "$PROGNAME: $CURLORWGET https://www.debian.org/devel/wnpp/rfa_bypackage" >&2; exit 1; }
 sed -ne 's/.*<li><a href="https\?:\/\/bugs.debian.org\/\([0-9]*\)">\([^:<]*\)[: ]*\([^<]*\)<\/a>.*/RFA \1 \2 -- \3/; T d; p; : d' $WNPPTMP >> $WNPP
 
-$GETCOMMAND $WNPPTMP http://www.debian.org/devel/wnpp/help_requested || \
-    { echo "$PROGNAME: $CURLORWGET http://www.debian.org/devel/wnpp/help_requested" >&2; exit 1; }
+$GETCOMMAND $WNPPTMP https://www.debian.org/devel/wnpp/help_requested || \
+    { echo "$PROGNAME: $CURLORWGET https://www.debian.org/devel/wnpp/help_requested" >&2; exit 1; }
 sed -ne 's/.*<li><a href="https\?:\/\/bugs.debian.org\/\([0-9]*\)">\([^:<]*\)[: ]*\([^<]*\)<\/a>.*/RFH \1 \2 -- \3/; T d; p; : d' $WNPPTMP >> $WNPP
 
 cut -f3 -d' ' $WNPP | sort > $WNPP_PACKAGES
@@ -120,7 +127,10 @@ else
 fi
 
 if [ -f "$WNPP_DIFF" ]; then
-    if [ -d "$CACHEDIR" ]; then
+    # This may fail when run from a cronjob (c.f., #309802), so just ignore it
+    # and carry on.
+    mkdir -p "$CACHEDIR" >/dev/null 2>&1 || true
+    if [ -d "$CACHEDIR" ] || [ -d "$OLDCACHEDIR" ]; then
         wnppdiff
         exit 0
     else
